from django.db.models.signals import pre_save
from django.dispatch import receiver
from django.contrib.sessions.models import Session


@receiver(pre_save)
def pre_save_full_clean_handler(sender, instance, *args, **kwargs):
    """ Force all models to call full_clean before save """
    if sender != Session:
        instance.full_clean()




from setuptools import setup

setup(
    name='django-fullclean',
    packages=['django_fullclean'],
    version='0.0.3',
    description='Force django model call full_clean before save.',
    author='Alfred Huang',
    author_email='57082212@qq.com',
    url='https://github.com/fish-ball/django-fullclean',
    download_url='https://github.com/fish-ball/django-fullclean/tarball/0.0.3',
    keywords=['django', 'model', 'validator', 'full_clean'],
    classifiers=[],
    license='MIT License',
    install_requires=['django'],
    platforms='any',
)
